==> kmud-0.5.tar.gz: kmud-0.5/kmud/dialogs/dlgmapoptionsdirections.cpp <==
/***************************************************************************
                          dlgmapoptionsdirections.cpp
                      -------------------
    description          :
    begin                : Fri Apr 28 2000
    copyright            : (C) 2000 by John-Paul Stanford
    email                : john-paul.stanford@virgin.net
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#include "dlgmapoptionsdirections.h"

DlgMapOptionsDirections::DlgMapOptionsDirections(QWidget *parent, const char *name) : QDialog(parent,name,true)
{
	initDialog();
}

DlgMapOptionsDirections::~DlgMapOptionsDirections()
{
}

void DlgMapOptionsDirections::setNorth(QString direction)
{ txtNorth->setText(direction); }

void DlgMapOptionsDirections::setNorthEast(QString direction)
{ txtNorthEast->setText(direction); }

void DlgMapOptionsDirections::setEast(QString direction)
{ txtEast->setText(direction); }

void DlgMapOptionsDirections::setSouthEast(QString direction)
{ txtSouthEast->setText(direction); }

void DlgMapOptionsDirections::setSouth(QString direction)
{ txtSouth->setText(direction); }

void DlgMapOptionsDirections::setSouthWest(QString direction)
{ txtSouthWest->setText(direction); }

void DlgMapOptionsDirections::setWest(QString direction)
{ txtWest->setText(direction); }

void DlgMapOptionsDirections::setNorthWest(QString direction)
{ txtNorthWest->setText(direction); }

void DlgMapOptionsDirections::setUp(QString direction)
{ txtUp->setText(direction); }

void DlgMapOptionsDirections::setDown(QString direction)
{ txtDown->setText(direction); }

QString DlgMapOptionsDirections::getNorth(void)
{ return txtNorth->text(); }

QString DlgMapOptionsDirections::getNorthEast(void)
{ return txtNorthEast->text(); }

QString DlgMapOptionsDirections::getEast(void)
{ return txtEast->text(); }

QString DlgMapOptionsDirections::getSouthEast(void)
{ return txtSouthEast->text(); }

QString DlgMapOptionsDirections::getSouth(void)
{ return txtSouth->text(); }

QString DlgMapOptionsDirections::getSouthWest(void)
{ return txtSouthWest->text(); }

QString DlgMapOptionsDirections::getWest(void)
{ return txtWest->text(); }

QString DlgMapOptionsDirections::getNorthWest(void)
{ return txtNorthWest->text(); }

QString DlgMapOptionsDirections::getUp(void)
{ return txtUp->text(); }

QString DlgMapOptionsDirections::getDown(void)
{ return txtDown->text(); }

==> kmud-1.0.tar.gz: kmud-1.0/kmud/dialogs/dlgmapoptionsdirections.cpp <==
/***************************************************************************
                          dlgmapoptionsdirections.cpp
                      -------------------
    description          :
    begin                : Fri Apr 28 2000
    copyright            : (C) 2000 by Kmud Developer Team
    email                : kmud-devel@kmud.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/

#include "dlgmapoptionsdirections.h"

DlgMapOptionsDirections::DlgMapOptionsDirections(QWidget *parent, const char *name) : QDialog(parent,name,true)
{
	initDialog();
}

DlgMapOptionsDirections::~DlgMapOptionsDirections()
{
}

void DlgMapOptionsDirections::setNorth(QString direction)
{ txtNorth->setText(direction); }

void DlgMapOptionsDirections::setNorthEast(QString direction)
{ txtNorthEast->setText(direction); }

void DlgMapOptionsDirections::setEast(QString direction)
{ txtEast->setText(direction); }

void DlgMapOptionsDirections::setSouthEast(QString direction)
{ txtSouthEast->setText(direction); }

void DlgMapOptionsDirections::setSouth(QString direction)
{ txtSouth->setText(direction); }

void DlgMapOptionsDirections::setSouthWest(QString direction)
{ txtSouthWest->setText(direction); }

void DlgMapOptionsDirections::setWest(QString direction)
{ txtWest->setText(direction); }

void DlgMapOptionsDirections::setNorthWest(QString direction)
{ txtNorthWest->setText(direction); }

void DlgMapOptionsDirections::setUp(QString direction)
{ txtUp->setText(direction); }

void DlgMapOptionsDirections::setDown(QString direction)
{ txtDown->setText(direction); }

QString DlgMapOptionsDirections::getNorth(void)
{ return txtNorth->text(); }

QString DlgMapOptionsDirections::getNorthEast(void)
{ return txtNorthEast->text(); }

QString DlgMapOptionsDirections::getEast(void)
{ return txtEast->text(); }

QString DlgMapOptionsDirections::getSouthEast(void)
{ return txtSouthEast->text(); }

QString DlgMapOptionsDirections::getSouth(void)
{ return txtSouth->text(); }

QString DlgMapOptionsDirections::getSouthWest(void)
{ return txtSouthWest->text(); }

QString DlgMapOptionsDirections::getWest(void)
{ return txtWest->text(); }

QString DlgMapOptionsDirections::getNorthWest(void)
{ return txtNorthWest->text(); }

QString DlgMapOptionsDirections::getUp(void)
{ return txtUp->text(); }

QString DlgMapOptionsDirections::getDown(void)
{ return txtDown->text(); }
